//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//	StringFunctors.h: --- operator functions in string context
//
//	DESCRIPTION:
//		Definition of prototypes of all string related operator classes
//		instantiated by the yacc/bison generated parser. These are:
//
//			o StrEq/StrNeq		- equality test
//			o StrLt/Le/Gt/Ge	- relational operators (lexicographical order)
//			o Upper/Lower		- change case
//			o Strlen			- string length
//			o Ascii				- ASCII value of first char in string
//			o StrConcat			- string concatenation
//			o StrRange			- range operator
//
//	CHANGE HISTORY:
//		UL, 2000-06-28: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Wed Jun 28 16:44:06 MET DST 2000
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/selcore/StringFunctors.h,v 1.1 2001/08/07 14:06:43 ulammers Exp $
///

#ifndef STRING_FUNCTORS_H
#define STRING_FUNCTORS_H

#include "Selector.h"
#include "SelectError.h"

#include <vector>

#define BEGINCLASS(a)					\
class a : public OperatorNode {			\
public:									\
	a();								\
	~a();

#define ENDCLASS };

#define OPCLASS1(a)		BEGINCLASS(a) a(const OpNode); ENDCLASS
#define OPCLASS2(a)		BEGINCLASS(a) a(const OpNode, const OpNode); ENDCLASS

//
//	operator classes
//
OPCLASS2(StrEq);
OPCLASS2(StrNe);
OPCLASS2(StrLt);
OPCLASS2(StrLe);
OPCLASS2(StrGt);
OPCLASS2(StrGe);

OPCLASS1(Upper);
OPCLASS1(Lower);

OPCLASS1(Strlen);
OPCLASS1(Ascii);

//
//	concatenation operator
//
OPCLASS2(StrConcat);

//
//	string range operators
//
class StrRange : public OperatorNode {
public:
	StrRange(bool lowerGiven, bool UpperGiven, OpNode c1 = 0, OpNode c2 = 0);
	~StrRange();
};

#undef BEGINCLASS
#undef ENDCLASS
#undef OPCLASS1
#undef OPCLASS2

#endif


