//--------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//--------------------------------------------------------------------------
//
//	basicdefs.h --- useful constants and macros of miscellaneous nature ---
//
//	DESCRIPTION:
//		This include file defines several useful macros
//
//	CHANGE HISTORY:
//		UL, 26/08/97: 1.0.0: - first version
//		UL, 19/05/98: 1.1.0: - more macros added
//
//	AUTHOR:
//		U. Lammers (UL), Wed Aug 27 11:48:12 MET DST 1997
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/selcore/basicdefs.h,v 1.3 2002/05/24 16:00:10 ulammers Exp $
//

#ifndef BASIC_H
#define BASIC_H

#ifdef __cplusplus
	#include <cassert>

	#define YYTEXT		(YYText())
#else
	#include <assert.h>

	#define YYTEXT		(yytext)
#endif

#define BOOL			int
#if defined(TRUE)
	#undef TRUE
#endif
#define TRUE			(1)
#if defined(FALSE)
	#undef FALSE
#endif
#define FALSE			(0)

//
//	-------------------( useful constants )------------------------------
//
#include "Celestial.h"

//
//	------------------( conversion functions )-----------------------------
//

#define DBL(a)			(static_cast<double>(a))
#define INT(a)			(static_cast<int>(a))
#define UNT(a)			(static_cast<unsigned>(a))
#define LNG(a)			(static_cast<long>(a))
#define ULNG(a)			(static_cast<unsigned long>(a))

//
//	---------------------( useful macros )--------------------------------
 
#define TOSTR(a)			#a
#define CSTR(a)				TOSTR(a)

#define YCAT(a, b)			a ## b
#define CAT(a, b)			YCAT(a, b)
#define CCAT(a, b, c)		CAT(CAT(a, b), c)

#define NUM_OF(x)			(sizeof(x)/sizeof(x[0]))
#define STREQ(a, b)			(std::strcmp((a), (b)) == 0)
#define STRIEQ(a, b)		(std::stricmp((a), (b)) == 0)
#define STRNCPY(a, b)		(std::strncpy(a, b, sizeof(a)))
#define TMALLOC(a)			((a *)std::malloc(sizeof(a)))
#define TSMALLOC(a, n)		((a *)std::malloc((n) * sizeof(a)))
#define TGETMEM(var, type)	{ var = TMALLOC(type); assert(var); }

#ifdef MIN
	#undef MIN
#endif
#define MIN(a, b)			((a) <= (b) ? (a) : (b))
#ifdef MAX
	#undef MAX
#endif
#define MAX(a, b)			((a) >= (b) ? (a) : (b))

#define MINMAX(a, b, c)		(MIN((c), MAX((a), (b))))

#define PERCENTAGE(a, b)	((b) ? (100. * (double)(a)/(double)(b)) : 100.)

#endif


