//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//	SetTableColumn: --- a class representing a chain DataSet::Table::Column
//
//	DESCRIPTION:
//		Instances of class SetTableColumn represent a container for
//		a specification of a DataSet/Table/Column tuple. Table/Column
//		are optional. Syntax:
//
//			setname[:block[:column]] || setname::column || setname::
//
//	CHANGE HISTORY:
//		UL, 1999-04-14: 1.0.0: - first version
//		UL, 1999-05-05: 2.0.0: - added accessMode argument to constructors
//		UL, 2000-05-24: 2.1.0: - new static methods componentNames()
//
//	AUTHOR:
//		U. Lammers (UL), Wed Apr 14 17:54:08 MET DST 1999
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/utils/SetTableColumn.h,v 1.4 2002/12/17 17:48:12 jbakker Exp $
//

#ifndef SETTABLECOLUMN_H
#define SETTABLECOLUMN_H

#include <iosfwd>
#include <string>
#include "Dal.h"

class SetTableColumn {
public:
	SetTableColumn(const std::string &spec,
				   Dal::AccessMode accessMode = Dal::Read,
				   DataSetServer::MemoryModel memModel = DataSetServer::Low);

	static std::vector<std::string> componentNames(const std::string &name);

	DataSet *dataSet() const;
	Table	*table() const;
	Column	*column() const;

	~SetTableColumn();

private:
	std::string					_setName, _tableName, _columnName;
	Dal::AccessMode				_accessMode;
	DataSetServer::MemoryModel	_memModel;

	mutable DataSet		*_set;
	mutable Table		*_table;
	mutable Column		*_column;

	DataSet	*accessSet() const;
	Table	*accessTable() const;
};

std::ostream &operator<<(std::ostream &, const SetTableColumn &);


class SetBlock {
public:
	SetBlock(const std::string &spec, Dal::AccessMode accessMode = Dal::Read,
			 DataSetServer::MemoryModel memModel = DataSetServer::Low);

	static std::vector<std::string> componentNames(const std::string &name);

	DataSet *dataSet() const;
	Block	*block() const;
	Table	*table() const;
	Array	*array() const;

	~SetBlock();

private:
	std::string					_setName, _blockName;
	Dal::AccessMode				_accessMode;
	DataSetServer::MemoryModel	_memModel;

	mutable DataSet		*_set;
	mutable Block		*_block;

	DataSet	*accessSet() const;
};

std::ostream &operator<<(std::ostream &, const SetBlock &);

#endif

